import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
interface CharacterObject {
    value: string;
}
interface Character<N extends number> {
    character: string;
    value: string;
    postgres: string;
    get n(): N;
    toString(): string;
    toJSON(): CharacterObject;
    equals(string: string): boolean;
    equals(object: Character<N> | CharacterObject): boolean;
    safeEquals(string: string): SafeEquals<Character<N>>;
    safeEquals(object: Character<N> | CharacterObject): SafeEquals<Character<N>>;
}
interface CharacterConstructor<N extends number> {
    from(string: string): Character<N>;
    from(object: Character<N> | CharacterObject): Character<N>;
    safeFrom(string: string): SafeFrom<Character<N>>;
    safeFrom(object: Character<N> | CharacterObject): SafeFrom<Character<N>>;
    /**
     * Returns `true` if `object` is a `Character`, `false` otherwise.
     */
    isCharacter(object: any): object is Character<N>;
    /**
     * Returns `true` if `object` is a `Character<N>`, `false` otherwise.
     */
    isCharacter<NN extends number = N>(object: any, n: NN): object is Character<NN>;
    /**
     * Returns `true` if `object` is a `Character<N>`, `false` otherwise.
     */
    isAnyCharacter(object: any): object is Character<number>;
    /**
     * Get a `Character` constructor for a specific `n`.
     * @param n The number of characters.
     */
    setN<N extends number = 1>(n: N): CharacterConstructor<N>;
    /**
     * Get the `n` value for this `Character` constructor.
     * @returns The `n` value.
     */
    get n(): N;
}
declare const Character: CharacterConstructor<1>;
export { Character, CharacterConstructor, CharacterObject };
