import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
declare enum IntervalStyle {
    PostgreSQL = "PostgreSQL",
    PostgreSQLShort = "PostgreSQL-Short",
    PostgreSQLTime = "PostgreSQL-Time",
    PostgreSQLTimeShort = "PostgreSQL-Time-Short",
    ISO = "ISO",
    ISOShort = "ISO-Short",
    ISOBasic = "ISO-Basic",
    ISOExtended = "ISO-Extended",
    SQL = "SQL"
}
type IntervalPostgreSQLStyles = "PostgreSQL" | "PostgreSQL-Short" | "PostgreSQL-Time" | "PostgreSQL-Time-Short";
type IntervalISOStyles = "ISO" | "ISO-Short" | "ISO-Basic" | "ISO-Extended";
type IntervalSQLStyles = "SQL";
type IntervalStyleType = IntervalPostgreSQLStyles | IntervalISOStyles | IntervalSQLStyles;
interface IntervalObject {
    years?: number;
    months?: number;
    days?: number;
    hours?: number;
    minutes?: number;
    seconds?: number;
    milliseconds?: number;
}
interface Interval {
    years: number;
    months: number;
    days: number;
    hours: number;
    minutes: number;
    seconds: number;
    milliseconds: number;
    value: string;
    postgres: string;
    /**
     * @param style The style to use when converting the interval to a string. Defaults to `PostgreSQL`.
     * @returns The interval as a string.
     * @example
     * const interval = Interval.from("1 year 2 months 4 hours 5 minutes 6 seconds 7 milliseconds");
     *
     * interval.toString(); // "1 year 2 months 4 hours 5 minutes 6 seconds 7 milliseconds"
     * interval.toString("PostgreSQL"); // "1 year 2 months 4 hours 5 minutes 6 seconds 7 milliseconds"
     * interval.toString("PostgreSQL-Short"); // "1 yr 2 mons 4hrs 5mins 6secs 7msecs"
     * interval.toString("PostgreSQL-Time"); // "1 year 2 months 04:05:06.007"
     * interval.toString("PostgreSQL-Time-Short"); // "1 yr 2 mons 04:05:06.007"
     * interval.toString("ISO"); // "P1Y2M0DT4H5M6.007S"
     * interval.toString("ISO-Short"); // "P1Y2M4TH5M6.007S"
     * interval.toString("ISO-Basic"); // "P00010200T040506.007"
     * interval.toString("ISO-Extended"); // "P0001-02-00T04:05:06.007"
     * interval.toString("SQL"); // "1-2 04:05:06.007"
     */
    toString(style?: IntervalStyle | IntervalStyleType): string;
    toJSON(): IntervalObject;
    equals(string: string): boolean;
    equals(object: Interval | IntervalObject): boolean;
    equals(years: number, months: number, days: number, hours: number, minutes: number, seconds: number, milliseconds: number): boolean;
    safeEquals(string: string): SafeEquals<Interval>;
    safeEquals(object: Interval | IntervalObject): SafeEquals<Interval>;
    safeEquals(years: number, months: number, days: number, hours: number, minutes: number, seconds: number, milliseconds: number): SafeEquals<Interval>;
}
interface IntervalConstructor {
    from(string: string): Interval;
    from(years: number, months: number, days: number, hours: number, minutes: number, seconds: number, milliseconds: number): Interval;
    from(object: Interval | IntervalObject): Interval;
    safeFrom(string: string): SafeFrom<Interval>;
    safeFrom(years: number, months: number, days: number, hours: number, minutes: number, seconds: number, milliseconds: number): SafeFrom<Interval>;
    safeFrom(object: Interval | IntervalObject): SafeFrom<Interval>;
    /**
     * Returns `true` if `object` is a `Interval`, `false` otherwise.
     */
    isInterval(object: any): object is Interval;
}
declare const Interval: IntervalConstructor;
export { Interval, IntervalConstructor, IntervalObject, IntervalStyle, IntervalStyleType };
