import { DateTime, Zone } from "luxon";
import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
interface TimeObject {
    hour: number;
    minute: number;
    second: number;
}
interface Time {
    hour: number;
    minute: number;
    second: number;
    value: number;
    postgres: string;
    toString(): string;
    toNumber(): number;
    toJSON(): TimeObject;
    /**
     * @param zone The zone to convert the time to. Defaults to 'local'.
     */
    toDateTime(zone?: string | Zone | undefined): DateTime;
    /**
     * @param zone The zone to convert the time to. Defaults to 'local'.
     */
    toJSDate(zone?: string | Zone | undefined): globalThis.Date;
    equals(string: string): boolean;
    equals(unixTimestamp: number): boolean;
    equals(hour: number, minute: number, second: number): boolean;
    equals(time: Time | globalThis.Date | DateTime): boolean;
    equals(object: TimeObject): boolean;
    safeEquals(string: string): SafeEquals<Time>;
    safeEquals(unixTimestamp: number): SafeEquals<Time>;
    safeEquals(hour: number, minute: number, second: number): SafeEquals<Time>;
    safeEquals(time: Time | globalThis.Date | DateTime): SafeEquals<Time>;
    safeEquals(object: TimeObject): SafeEquals<Time>;
}
interface TimeConstructor {
    from(string: string): Time;
    from(unixTimestamp: number): Time;
    from(hour: number, minute: number, second: number): Time;
    from(time: Time | globalThis.Date | DateTime): Time;
    from(object: TimeObject): Time;
    safeFrom(string: string): SafeFrom<Time>;
    safeFrom(unixTimestamp: number): SafeFrom<Time>;
    safeFrom(hour: number, minute: number, second: number): SafeFrom<Time>;
    safeFrom(time: Time | globalThis.Date | DateTime): SafeFrom<Time>;
    safeFrom(object: TimeObject): SafeFrom<Time>;
    /**
     * Returns `true` if `object` is a `Time`, `false` otherwise.
     */
    isTime(object: any): object is Time;
}
declare const Time: TimeConstructor;
export { Time, TimeConstructor, TimeObject };
