import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
import { Point, type PointObject } from "./Point.js";
interface LineSegmentObject {
    a: Point;
    b: Point;
}
interface RawLineSegmentObject {
    a: PointObject;
    b: PointObject;
}
interface LineSegment {
    a: Point;
    b: Point;
    value: string;
    postgres: string;
    toString(): string;
    toJSON(): RawLineSegmentObject;
    equals(string: string): boolean;
    equals(a: Point, b: Point): boolean;
    equals(points: [Point, Point]): boolean;
    equals(lineSegment: LineSegment): boolean;
    equals(object: LineSegmentObject | RawLineSegmentObject): boolean;
    safeEquals(string: string): SafeEquals<LineSegment>;
    safeEquals(a: Point, b: Point): SafeEquals<LineSegment>;
    safeEquals(points: [Point, Point]): SafeEquals<LineSegment>;
    safeEquals(lineSegment: LineSegment): SafeEquals<LineSegment>;
    safeEquals(object: LineSegmentObject | RawLineSegmentObject): SafeEquals<LineSegment>;
}
interface LineSegmentConstructor {
    from(string: string): LineSegment;
    from(a: Point, b: Point): LineSegment;
    from(points: [Point, Point]): LineSegment;
    from(lineSegment: LineSegment): LineSegment;
    from(object: LineSegmentObject | RawLineSegmentObject): LineSegment;
    safeFrom(string: string): SafeFrom<LineSegment>;
    safeFrom(a: Point, b: Point): SafeFrom<LineSegment>;
    safeFrom(points: [Point, Point]): SafeFrom<LineSegment>;
    safeFrom(lineSegment: LineSegment): SafeFrom<LineSegment>;
    safeFrom(object: LineSegmentObject | RawLineSegmentObject): SafeFrom<LineSegment>;
    /**
     * Returns `true` if `object` is a `LineSegment`, `false` otherwise.
     */
    isLineSegment(object: any): object is LineSegment;
}
declare const LineSegment: LineSegmentConstructor;
export { LineSegment, LineSegmentConstructor, LineSegmentObject, RawLineSegmentObject };
