/* eslint-disable unicorn/filename-case */
import { isValid } from "@postgresql-typed/util";
import { getErrorMap } from "./errorMap.js";
import { PGTPBase } from "./PGTPBase.js";
import { PGTPError } from "./PGTPError.js";
export class PGTPRangeBase extends PGTPBase {
    constructor() {
        super();
        this.isWithinRange = this.isWithinRange.bind(this);
        this.safeIsWithinRange = this.safeIsWithinRange.bind(this);
    }
    isWithinRange(...data) {
        const result = this.safeIsWithinRange(...data);
        if (result.success)
            return result.isWithinRange;
        throw result.error;
    }
    safeIsWithinRange(...data) {
        const context = {
            issue: null,
            errorMap: getErrorMap(),
            data,
        }, result = this._isWithinRange(context);
        return this._handleWithinResult(context, result);
    }
    _handleWithinResult(context, result) {
        if (isValid(result)) {
            return {
                success: true,
                isWithinRange: result.value.isWithinRange,
                data: result.value.data,
            };
        }
        if (!context.issue)
            throw new Error("Validation failed but no issue detected.");
        const error = new PGTPError(context.issue);
        return { success: false, error };
    }
}
//# sourceMappingURL=PGTPRangeBase.js.map